Under the Hood
==============

This page explains how ``asyncslot`` is implemented.

We first give an overview of how ``asyncio`` works.  We then give an
overview of how Qt works.  We then explain how ``asyncslot`` make them
work together nicely.  Finally we note some points of interest.
